%define anolis_release 1
# We need to break some cycles with optional dependencies for bootstrapping;
# given that a conditional is needed, we take the opportunity to omit as many
# optional dependencies as possible for bootstrapping.
%bcond_without bootstrap

# When not bootstrapping, run tests?
%bcond_without tests
%{?with_bootstrap:%undefine with_tests}
# When running tests, run ones that are marked as slow?
%bcond_without slow_tests
# When running tests, run ones that cannot be run in parallel?
%bcond_without single_tests

Name:           python-pandas
Version:        1.5.3
Release:        %{anolis_release}%{?dist}
Summary:        Python library providing high-performance data analysis tools

# The entire source is BSD-3-Clause and covered by LICENSE, except:
#
# - pandas/util/version/__init__.py is (Apache-2.0 OR BSD-2-Clause): see
#   LICENSES/PACKAGING_LICENSE
# - pandas/_libs/src/headers/portable.h is (BSD-3-Clause AND MIT), because it
#   contains some trivial content under the overall BSD-3-Clause license but
#   also some macros from MUSL libc under the MIT license: see
#   LICENSES/MUSL_LICENSE
# - pandas/_libs/src/parser/tokenizer.c is (BSD-3-Clause AND Python-2.0.1): see
#   LICENSES/PSF_LICENSE
# - pandas/io/sas/sas7bdat.py is (BSD-3-Clause and MIT), because it is mostly
#   under the overall BSD-3-Clause license but is also based on
#   https://bitbucket.org/jaredhobbs/sas7bdat: see LICENSES/SAS7BDAT_LICENSE
# - pandas/core/accessor.py is (BSD-3-Clause AND Apache-2.0), because it is
#   partially under the overall BSD-3-Clause license but is also based on
#   xarray: see LICENSES/XARRAY_LICENSE
# - pandas/_libs/src/klib/khash.h is MIT: see LICENSES/KLIB_LICENSE
# - pandas/_libs/window/aggregations.pyx is (BSD-3-Clause AND BSD-2-Clause):
#   see “Bottleneck license” in LICENSES/OTHER
#
# In the python3-pandas+tests subpackage:
#
# - pandas/tests/io/data/spss/*.sav are MIT: see LICENSES/HAVEN_LICENSE and
#   LICENSES/HAVEN_MIT
# - pandas/tests/window/test_rolling.py is (BSD-3-Clause AND BSD-2-Clause)
#   since test_rolling_std_neg_sqrt is from Bottleneck: see “Bottleneck license”
#   in LICENSES/OTHER
#
# Additionally:
#
# - pandas/_libs/tslibs/parsing.pyx is BSD-3-Clause rather than
#   (BSD-3-Clause AND (BSD-3-Clause OR Apache-2.0)), because it appears that at
#   least some trivial content in the code copied from dateutil in the
#   dateutil_parse() function (as of
#   https://github.com/dateutil/dateutil/pull/732) is by dateutil contributors
#   who have not agreed to re-license their previously submitted code: see
#   LICENSES/DATEUTIL_LICENSE.
# - LICENSES/OTHER suggests that some code may be derived from
#   google-api-python-client under Apache-2.0, but a search for attribution
#   comments did not turn up anything specific
# - pandas/_libs/tslibs/src/datetime/np_datetime.{h,c} are still BSD-3-Clause,
#   but see also LICENSES/NUMPY_LICENSE
# - pandas/io/clipboard/ is still BSD-3-Clause, but see also “Pyperclip v1.3
#   license” in LICENSES/OTHER
# - pandas/_testing/__init__.py is still BSD-3-Clause, but see also
#   LICENSES/SCIPY_LICENSE
# - pandas/_libs/src/ujson/lib/ is still BSD-3-Clause, but under
#   LICENSES/ULTRAJSON_LICENSE
#
# Additionally, the following are not packaged and so do not affect the overall
# License field:
#
# - scripts/no_bool_in_generic.py is MIT: see LICENSES/PYUPGRADE_LICENSE
License:        BSD-3-Clause AND (Apache-2.0 OR BSD-2-Clause) AND (BSD-3-Clause AND Apache-2.0) AND (BSD-3-Clause AND MIT) AND (BSD-3-Clause AND Python-2.0.1) AND MIT AND (BSD-3-Clause AND BSD-2-Clause)
URL:            https://pandas.pydata.org/
# The GitHub archive contains tests; the PyPI sdist does not.
Source0:        https://github.com/pandas-dev/pandas/archive/v%{version}/pandas-%{version}.tar.gz

# Fix some little-endian assumptions in the tests
# https://github.com/pandas-dev/pandas/pull/49913
Patch:          https://github.com/pandas-dev/pandas/pull/49913.patch

# [PATCH] Backport PR #50925 on branch 1.5.x (TST: Remove fsspec internals from
# tests) (#51038)
#
# TST: Remove fsspec internals from tests (#50925)
# https://github.com/pandas-dev/pandas/commit/e73d4d29203dab20e001beb1090d07683de583d6
#   fixes:
# ERROR at setup of test_to_read_gcs[…]
Patch:          https://github.com/pandas-dev/pandas/commit/e73d4d29203dab20e001beb1090d07683de583d6.patch

# Fix/mpl37 compat
# https://github.com/pandas-dev/pandas/pull/52150
#   Fixes:
# python-pandas: FTBFS in Fedora rawhide/f38
# https://bugzilla.redhat.com/show_bug.cgi?id=2171682
Patch:          https://github.com/pandas-dev/pandas/pull/52150.patch

# CI: Unpin pyarrow<10
# https://github.com/pandas-dev/pandas/pull/50314
#
# Merged upstream as 4878dfe551da2fa8e2bc33e774b595f099bfa74e:
#   CI: Unpin pyarrow<10 (#50314)
#   * CI: Unpin pyarrow<10
#   * Skip test
#
# ----
#
# Add pandas.compat.pa_version_under11p0, required for pyarrow 11 support, from
# the following PR/commit, but without the other associated changes:
#
# ENH: support reductions for pyarrow temporal types (#50998)
# https://github.com/pandas-dev/pandas/pull/50998
#
# Merged upstream as 52306d957cb77a3823624679bb9606e244e7faa8:
#   ENH: support reductions for pyarrow temporal types
#   * unit check
#   * lint fixup
#
# ----
#
# CI: unpin pyarrow, fix failing test
# https://github.com/pandas-dev/pandas/pull/51175
#
# Merged upstream as 5f584bd29be7203db64bdf8619991927e29c74bc:
#   CI: unpin pyarrow, fix failing test (#51175)
#   * unpin pyarrow, fix failing test
#   * cleanup
#   * handle NaT/NaN
#
# ----
#
# All commits cherry-picked to tag v1.5.3 and combined into a single patch.
Patch:          pandas-1.5.3-pyarrow-10-11.patch

%global _description %{expand:
pandas is an open source, BSD-licensed library providing
high-performance, easy-to-use data structures and data
analysis tools for the Python programming language.}

%description %_description


%package -n python3-pandas
Summary:        %{summary}

# pandas/_libs/window/aggregations.pyx:
#
#   Moving maximum / minimum code taken from Bottleneck under the terms
#   of its Simplified BSD license
#   https://github.com/pydata/bottleneck
#
# These snippets are extracted from Bottleneck’s internals and cannot be
# replaced by calling the public Bottleneck API, so there is no reasonable path
# to unbundling.
Provides:       bundled(python3dist(bottleneck))

# pandas/_libs/tslibs/parsing.pyx:
#
# Contains a routine, dateutil_parse(), from an unspecified version of dateutil
#
# Cannot be unbundled because the function is forked and compiled as Cython
Provides:       bundled(python3dist(dateutil))

# pandas/_libs/src/klib/khash.h:
#
# From klib (https://github.com/attractivechaos/klib); it is not practical to
# package all of klib separately because it is designed as a copylib, and many
# of its components are not header-only.
Provides:       bundled(klib-khash) = 0.2.6

# pandas/_libs/src/headers/portable.h:
#
# Contains several preprocessor macros from an unspecified version of MUSL libc
#
# Cannot be unbundled because the macros are not directly exposed in the libc
Provides:       bundled(musl-libc)

# pandas/_libs/tslibs/src/datetime/np_datetime.{h,c}:
#
# Derived from Numpy 1.7
#
# Cannot be unbundled because the routines are forked.
Provides:       bundled(python3dist(numpy)) = 1.7

# pandas/util/version/__init__.py:
#
# Vendored from https://github.com/pypa/packaging/blob/main/packaging/_structures.py
# and https://github.com/pypa/packaging/blob/main/packaging/_structures.py
# changeset ae891fd74d6dd4c6063bb04f2faeadaac6fc6313
# 04/30/2021
#
# Cannot be (reasonably) unbundled because the vendored file is not part of
# packaging’s public API.
Provides:       bundled(python3dist(packaging)) = 20.10.dev0^20210430gitae891fd

# pandas/io/clipboard/:
#
# In https://github.com/pandas-dev/pandas/pull/28471, upstream considered and
# rejected the idea of de-vendoring pyperclip. Furthermore,
# https://github.com/pandas-dev/pandas/commits/main/pandas/io/clipboard and
# https://github.com/pandas-dev/pandas/commits/main/pandas/io/clipboard/__init__.py
# show that the vendored library has accrued Pandas-specific changes.
#
# Version number from:
# https://github.com/pandas-dev/pandas/pull/28471/commits/33cd2d72e0c007c460e59105efda9211441b2ce4
# “Updated internal pyperclip 1.5.27 -> 1.7.0”
Provides:       bundled(python3dist(pyperclip)) = 1.7.0

# pandas/_libs/src/parser/tokenizer.c:
#
# Combines some elements from Python's built-in csv module and Warren
# Weckesser's textreader project on GitHub.
#
# Elements from these are both forked and cannot be unbundled. The textreader
# project is a Python extension but is not on PyPI, and is not the same as
# python3dist(textreader).
Provides:       bundled(python3-libs)
Provides:       bundled(textreader)

# scripts/no_bool_in_generic.py:
#
# The function `visit` is adapted from a function by the same name in pyupgrade:
# https://github.com/asottile/pyupgrade/blob/5495a248f2165941c5d3b82ac3226ba7ad1fa59d/pyupgrade/_data.py#L70-L113
#
# Not packaged (pre-commit hook) therefore not bundled
# Provides:       bundled(python3dist(pyupgrade)) = 2.11.0^20210201git5495a24

# pandas/io/sas/sas7bdat.py
#
# Based on code written by Jared Hobbs:
#   https://bitbucket.org/jaredhobbs/sas7bdat
#
# Cannot be unbundled because the code is modified, not directly copied
Provides:       bundled(python3dist(sas7bdat))

# pandas/_testing/__init__.py: in _create_missing_idx():
#
#   below is cribbed from scipy.sparse
#
# Cannot be unbundled because only a few lines are copied, not a standalone
# function that we can call
Provides:       bundled(python3dist(scipy))

# pandas/_libs/src/ujson/lib/:
#
# This is a stripped-down copy of UltraJSON. It would be an obvious target for
# unbundling, except:
#
# - Pandas uses the C library API, but UltraJSON upstream does not support
#   building and installing it separately from the Python package.
# - In https://github.com/pandas-dev/pandas/issues/24711 it is suggested that
#   Pandas might rely on features of the particular vendored version of
#   UltraJSON. It’s not immediately clear whether this is still true or not.
Provides:       bundled(python3dist(ujson))

# pandas/core/accessor.py
#
#   Ported with modifications from xarray
#   https://github.com/pydata/xarray/blob/master/xarray/core/extensions.py
#   1. We don't need to catch and re-raise AttributeErrors as RuntimeErrors
#   2. We use a UserWarning instead of a custom Warning
#
# Cannot be unbundled because the copied code is forked.
Provides:       bundled(python3dist(xarray))

BuildRequires:  gcc
BuildRequires:  gcc-c++

BuildRequires:  python3-devel

# Since numpy is imported in setup.py, we need it to generate BR’s. This only
# becomes obvious during bootstrapping, in which the many optional dependencies
# that indirectly require numpy are removed.
BuildRequires:  python3dist(numpy)

%if %{without bootstrap}

# doc/source/getting_started/install.rst “Recommended dependencies”
# Since these provide large speedups, we make them hard dependencies except
# during bootstrapping.
BuildRequires:  python3dist(numexpr) >= 2.7.3
Requires:       python3dist(numexpr) >= 2.7.3
BuildRequires:  python3dist(bottleneck) >= 1.3.2
Requires:       python3dist(bottleneck) >= 1.3.2

# doc/source/getting_started/install.rst “Optional dependencies”
# We BR all weak dependencies to ensure they are installable.

# Timezones
BuildRequires:  tzdata >= 2022a
Recommends:     tzdata >= 2022a

# Visualization
BuildRequires:  python3dist(matplotlib) >= 3.3.2
Recommends:     python3dist(matplotlib) >= 3.3.2
BuildRequires:  python3dist(jinja2) >= 3
Recommends:     python3dist(jinja2) >= 3
BuildRequires:  python3dist(tabulate) >= 0.8.9
Recommends:     python3dist(tabulate) >= 0.8.9

# Computation
BuildRequires:  python3dist(scipy) >= 1.7.1
Recommends:     python3dist(scipy) >= 1.7.1
# python-numba is not currently packaged:
# BuildRequires:  python3dist(numba) >= 0.46
# Recommends:     python3dist(numba) >= 0.46
BuildRequires:  python3dist(xarray) >= 1.19
Recommends:     python3dist(xarray) >= 1.19

# Excel files
BuildRequires:  python3dist(xlrd) >= 2.0.1
Recommends:     python3dist(xlrd) >= 2.0.1
BuildRequires:  python3dist(xlwt) >= 1.3
Recommends:     python3dist(xlwt) >= 1.3
BuildRequires:  python3dist(xlsxwriter) >= 1.4.3
Recommends:     python3dist(xlsxwriter) >= 1.4.3
BuildRequires:  python3dist(openpyxl) >= 3.0.7
Recommends:     python3dist(openpyxl) >= 3.0.7
# python-pyxlsb is not currently packaged:
# BuildRequires:  python3dist(pyxlsb) >= 1.0.8
# Recommends:     python3dist(pyxlsb) >= 1.0.8
# Not in doc/source/getting_started/install.rst, but in environment.yml and in
# some doc-strings:
BuildRequires:  python3dist(odfpy) >= 1.4.1
Recommends:     python3dist(odfpy) >= 1.4.1

# HTML
BuildRequires:  python3dist(beautifulsoup4) >= 4.9.3
Recommends:     python3dist(beautifulsoup4) >= 4.9.3
BuildRequires:  python3dist(html5lib) >= 1.1
Recommends:     python3dist(html5lib) >= 1.1
# lxml handled below:

# XML
BuildRequires:  python3dist(lxml) >= 4.6.3
Recommends:     python3dist(lxml) >= 4.6.3

# SQL databases
BuildRequires:  python3dist(sqlalchemy) >= 1.4.16
Recommends:     python3dist(sqlalchemy) >= 1.4.16
BuildRequires:  python3dist(psycopg2) >= 2.8.6
Recommends:     python3dist(psycopg2) >= 2.8.6
BuildRequires:  python3dist(pymysql) >= 1.0.2
Recommends:     python3dist(pymysql) >= 1.0.2

# Other data sources
BuildRequires:  python3dist(tables) >= 3.6.1
Recommends:     python3dist(tables) >= 3.6.1
# Dependencies on blosc and zlib are indirect, via PyTables, so we do not
# encode them here. Note also that the minimum blosc version in the
# documentation seems to be that of the blosc C library, not of the blosc PyPI
# package.
# python-fastparquet is not currently packaged:
# BuildRequires:  python3dist(fastparquet) >= 0.4
# Recommends:     python3dist(fastparquet) >= 0.4
# libarrow does not support 32-bit architectures:
%if 0%{?__isa_bits} != 32
BuildRequires:  python3dist(pyarrow) >= 1.0.1
Recommends:     python3dist(pyarrow) >= 1.0.1
%endif
# python-pyreadstat is not currently packaged:
# BuildRequires:  python3dist(pyreadstat) >= 1.1.2
# Recommends:     python3dist(pyreadstat) >= 1.1.2

# Access data in the cloud
BuildRequires:  python3dist(fsspec) >= 2021.7
Recommends:     python3dist(fsspec) >= 2021.7
# python-gcsfs is packaged, but is badly out of date in F37 and older:
# https://bugzilla.redhat.com/show_bug.cgi?id=2136233
BuildRequires:  python3dist(gcsfs) >= 2021.7
Recommends:     python3dist(gcsfs) >= 2021.7
# python-pandas-gbq is not currently packaged:
# BuildRequires:  python3dist(pandas-gbq) >= 0.15
# Recommends:     python3dist(pandas-gbq) >= 0.15
# python-s3fs is not currently packaged:
# BuildRequires:  python3dist(s3fs) >= 2021.8
# Recommends:     python3dist(s3fs) >= 2021.8

# Clipboard
BuildRequires:  python3dist(pyqt5)
Recommends:     python3dist(pyqt5)
BuildRequires:  python3dist(qtpy)
Recommends:     python3dist(qtpy)
BuildRequires:  xclip
Recommends:     xclip
BuildRequires:  xsel
Recommends:     xsel

# Compression
BuildRequires:  python3dist(brotli) >= 0.7
Recommends:     python3dist(brotli) >= 0.7
BuildRequires:  python3dist(python-snappy) >= 0.6
Recommends:     python3dist(python-snappy) >= 0.6
BuildRequires:  python3dist(zstandard) >= 0.15.2
Recommends:     python3dist(zstandard) >= 0.15.2

# This is just an “ecosystem” package in the upstream documentation, but there
# is an integration test for it. This package historically had a weak
# dependency on it, but this was unnecessary.
BuildRequires:  python3dist(pandas-datareader)

%endif

%description -n python3-pandas %_description


%package -n python3-pandas+test
Summary:        Tests and test extras for Pandas

# See comment above base package License tag for licensing breakdown.
License:        BSD-3-Clause AND MIT

Requires:       python3-pandas = %{version}-%{release}

%if %{without bootstrap}

# Additional BR’s and weak dependencies below are generally those that don’t
# provide enough added functionality to be weak dependencies of the library
# package, but for which there is some integration support and additional tests
# that can be enabled.

# Additional dependencies from environment.yml: “testing”
# Those not in the “test” extra are treated as weak dependencies for the tests.
BuildRequires:  python3dist(boto3)
Recommends:     python3dist(boto3)
BuildRequires:  python3dist(botocore) >= 1.11
Recommends:     python3dist(botocore) >= 1.11
# Already covered by “test” extra
# BuildRequires:  python3dist(hypothesis) >= 3.82
# Recommends:     python3dist(hypothesis) >= 3.82
# python-moto is not yet packaged
# BuildRequires:  python3dist(moto)
# Recommends:     python3dist(moto)
BuildRequires:  python3dist(flask)
Recommends:     python3dist(flask)
# Already covered by “test” extra
# BuildRequires:  python3dist(pytest) >= 5.0.1
# Requires:       python3dist(pytest) >= 5.0.1
# BuildRequires:  python3dist(pytest-cov)
# Recommends:     python3dist(pytest-cov)
# Already covered by “test” extra
# BuildRequires:  python3dist(pytest-xdist) >= 1.21
# Requires:       python3dist(pytest-xdist) >= 1.21
BuildRequires:  python3dist(pytest-asyncio)
Recommends:     python3dist(pytest-asyncio)
# python-pytest-instafail is not yet packaged
# BuildRequires:  python3dist(pytest-instafail)
# Recommends:     python3dist(pytest-instafail)

# Additional dependencies from environment.yml:
# “Dask and its dependencies (that dont install with dask)”
# Asks for dask-core, but we just have dask
BuildRequires:  python3dist(dask)
Recommends:     python3dist(dask)
BuildRequires:  python3dist(toolz) >= 0.7.3
Recommends:     python3dist(toolz) >= 0.7.3
BuildRequires:  python3dist(partd) >= 0.3.10
Recommends:     python3dist(partd) >= 0.3.10
BuildRequires:  python3dist(cloudpickle) >= 0.2.1
Recommends:     python3dist(cloudpickle) >= 0.2.1

# Additional dependencies from environment.yml: “downstream tests”
BuildRequires:  python3dist(seaborn)
Recommends:     python3dist(seaborn)
BuildRequires:  python3dist(statsmodels)
Recommends:     python3dist(statsmodels)

# environment.yml: Needed for downstream xarray.CFTimeIndex test
BuildRequires:  python3dist(cftime)
Recommends:     python3dist(cftime)

# environment.yml: optional
BuildRequires:  python3dist(ipython) >= 7.11.1
Recommends:     python3dist(ipython) >= 7.11.1

# pandas/tests/io/data/spss/*.sav:
#
# From Haven
Provides:       bundled(R-haven)

# pandas/tests/window/test_rolling.py: test_rolling_std_neg_sqrt()
#
#   unit test from Bottleneck
#
# There is no reasonable path to unbundling a single unit test.
Provides:       bundled(python3dist(bottleneck))

%endif


%description -n python3-pandas+test
These are the tests for python3-pandas. This package:

• Provides the “pandas.tests” package
• Makes sure the “test” extra dependencies are installed
• Carries additonal weak dependencies for running the tests


%prep
%autosetup -n pandas-%{version} -p1

# Ensure Cython-generated sources are re-generated
rm -vf $(grep -rl '/\* Generated by Cython')

# We just want to build with the numpy in Fedora:
sed -r -i '/\boldest-supported-numpy\b/d' pyproject.toml


%generate_buildrequires
%pyproject_buildrequires -r %{?with_tests:-x test}


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files pandas


%check
%if %{with tests}

# Clipboard tests don’t run without a graphical session, and it’s not worth
# using xvfb-run just for them.
m="${m-}${m+ and }not clipboard"
%if %{without single_tests}
m="${m-}${m+ and }not single"
%endif

# This test allocates a huge amount of memory (~12GB), which causes flaky OOM
# failures on some builders. It’s not worth it.
# https://github.com/pandas-dev/pandas/issues/45223#issuecomment-1250912663
k="${k-}${k+ and }not test_bytes_exceed_2gb"

# This test (only) expects the current working directory to be the
# site-packages directory containing the built pandas. This is not how we run
# the tests, because we don’t want to clutter the buildroot with
# testing-related hidden files and directories. We could run tests from
# %%pyproject_build_lib if this were a problem for a lot of tests, but it’s
# easier just to skip it.
k="${k-}${k+ and }not test_html_template_extends_options"

# TODO: Why does this fail?
# E           assert 0 == 1
k="${k-}${k+ and }not test_switch_options"

%ifarch x86_64
# These are brittle and fail with tiny floating-point differences on COPR
# builders but not Koji builders, like:
# >           raise_assert_detail(obj, msg, left, right, index_values=index_values)
# E           AssertionError: numpy array are different
# E
# E           numpy array values are different (16.66667 %)
# E           [left]:  [0.09999999999999999, 1.0, 10.0, 100.0, 1000.0, 10000.0]
# E           [right]: [0.1, 1.0, 10.0, 100.0, 1000.0, 10000.0]
k="${k-}${k+ and }not (TestSeriesPlots and test_bar_log)"
k="${k-}${k+ and }not (TestDataFramePlotsSubplots and test_bar_log_no_subplots)"
k="${k-}${k+ and }not (TestDataFramePlotsSubplots and test_bar_log_subplots)"
%endif

# TODO: Why does this fail? Does it need a slightly older version of dask?
k="${k-}${k+ and }not test_construct_dask_float_array_int_dtype_match_ndarray"

# Incompatibility with python-xarray ≥ 2023.01.0. See:
# https://github.com/pydata/xarray/blob/v2023.02.0/doc/whats-new.rst#breaking-changes-1
# CFTimeIndex.get_loc() got an unexpected keyword argument 'method'
k="${k-}${k+ and }not test_xarray_cftimeindex_nearest"

# E       AssertionError: Did not use numexpr as expected.
# E       assert []
k="${k-}${k+ and }not (TestExpressions and test_run_binary)"

# Ensure pytest doesn’t find the “un-built” library. We can get away with this
# approach because the tests are also in the installed library. We can’t simply
# “cd” to the buildroot’s python3_sitearch because testing leaves files in the
# current working directory.
mkdir -p _empty
cd _empty

# See: test_fast.sh
# Workaround for pytest-xdist flaky collection order
# https://github.com/pytest-dev/pytest/issues/920
# https://github.com/pytest-dev/pytest/issues/1075
export PYTHONHASHSEED="$(
  %{python3} -c 'import random; print(random.randint(1, 4294967295))'
)"

# Previously, we ran tests in parallel. Upstream seems to support this;
# however, in practice, there were still some flaky test failures that seem to
# be fixed by eschewing parallelism.
#
# If we start running tests in parallel again in the future, note that on
# 32-bit platforms (%%if 0%%{?__isa_bits} == 32) it may be necessary to limit
# the number of concurrent tests to e.g. 8 in order to prevent memory
# exhaustion.
%constrain_build -c 1

%pytest -v '%{buildroot}%{python3_sitearch}/pandas' \
    %{?!with_slow_tests:--skip-slow} \
    --skip-network \
    --skip-db \
    -m "${m-}" \
    -k "${k-}" \
    -n %{_smp_build_ncpus} \
    -r sxX

%else
# Some imports require optional dependencies, and must be excluded during
# bootstrapping.
%{pyproject_check_import \
  %{?with_bootstrap:-e 'pandas.io.formats.style'} \
  %{?with_bootstrap:-e 'pandas.io.formats.style_render'} \
  %{?with_bootstrap:-e 'pandas.core.arrays.arrow.extension_types'} \
  -e 'pandas.conftest' \
  -e 'pandas.tests.*'}
%endif


%files -n python3-pandas -f %{pyproject_files}
# While pyproject_files automatically handles the LICENSE file in the Python
# package’s dist-info directory, we also want to package the entire LICENSES/
# directory to include third-party license text.  We include a second copy of
# the LICENSE file since it would be surprising to see a license directory for
# the package without the overall license file in it.
%license LICENSE LICENSES/
%doc README.md
%doc RELEASE.md
%exclude %{python3_sitearch}/pandas/tests


%files -n python3-pandas+test
%{python3_sitearch}/pandas/tests
%ghost %{python3_sitearch}/*.dist-info


%changelog
* Wed May 03 2023 Funda Wang <fundawang@yeah.net> - 1.5.3-1
- Import package for anolis 23
